Coverage for /home/kale/hacking/projects/tich_me/tich_me/app.py: 100%

# Coverage for /home/kale/hacking/projects/tich_me/tich_me/app.py : 100%

## 4 statements 4 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 | #!/usr/bin/env python3 from appdirs import AppDirs from pathlib import Path APP = AppDirs('tich_me') DB_PATH = Path(APP.user_data_dir) / 'tichu.db'